@@ -13,43 +13,43 @@
 #include <KMessageBox>
 
 #include "prefs.h"
-
+#include <KLazyLocalizedString>
 struct ListRef {
-    const char *text;
+    const KLazyLocalizedString text;
     long int num;
 };
 
-static ListRef date_itemlist[] = {{I18N_NOOP("Do not Care"), 0},
+static ListRef date_itemlist[] = {{kli18n("Do not Care"), 0},
 
-                                  {I18N_NOOP("30 Min"), 30 * 60},
-                                  {I18N_NOOP("1 Hour"), 1 * 60 * 60},
-                                  {I18N_NOOP("2 Hours"), 2 * 60 * 60},
-                                  {I18N_NOOP("4 Hours"), 4 * 60 * 60},
-                                  {I18N_NOOP("8 Hours"), 8 * 60 * 60},
-                                  {I18N_NOOP("12 Hours"), 12 * 60 * 60},
-                                  {I18N_NOOP("18 Hours"), 18 * 60 * 60},
+                                  {kli18n("30 Min"), 30 * 60},
+                                  {kli18n("1 Hour"), 1 * 60 * 60},
+                                  {kli18n("2 Hours"), 2 * 60 * 60},
+                                  {kli18n("4 Hours"), 4 * 60 * 60},
+                                  {kli18n("8 Hours"), 8 * 60 * 60},
+                                  {kli18n("12 Hours"), 12 * 60 * 60},
+                                  {kli18n("18 Hours"), 18 * 60 * 60},
 
-                                  {I18N_NOOP("1 Day"), 1 * 60 * 60 * 24},
-                                  {I18N_NOOP("2 Days"), 2 * 60 * 60 * 24},
-                                  {I18N_NOOP("3 Days"), 3 * 60 * 60 * 24},
-                                  {I18N_NOOP("4 Days"), 4 * 60 * 60 * 24},
-                                  {I18N_NOOP("5 Days"), 5 * 60 * 60 * 24},
-                                  {I18N_NOOP("6 Days"), 6 * 60 * 60 * 24},
+                                  {kli18n("1 Day"), 1 * 60 * 60 * 24},
+                                  {kli18n("2 Days"), 2 * 60 * 60 * 24},
+                                  {kli18n("3 Days"), 3 * 60 * 60 * 24},
+                                  {kli18n("4 Days"), 4 * 60 * 60 * 24},
+                                  {kli18n("5 Days"), 5 * 60 * 60 * 24},
+                                  {kli18n("6 Days"), 6 * 60 * 60 * 24},
 
-                                  {I18N_NOOP("1 Week"), 1 * 60 * 60 * 24 * 7},
-                                  {I18N_NOOP("2 Weeks"), 2 * 60 * 60 * 24 * 7},
-                                  {I18N_NOOP("3 Weeks"), 3 * 60 * 60 * 24 * 7},
-                                  {I18N_NOOP("4 Weeks"), 4 * 60 * 60 * 24 * 7},
+                                  {kli18n("1 Week"), 1 * 60 * 60 * 24 * 7},
+                                  {kli18n("2 Weeks"), 2 * 60 * 60 * 24 * 7},
+                                  {kli18n("3 Weeks"), 3 * 60 * 60 * 24 * 7},
+                                  {kli18n("4 Weeks"), 4 * 60 * 60 * 24 * 7},
 
-                                  {I18N_NOOP("1 Month"), 1 * 60 * 60 * 24 * 30},
-                                  {I18N_NOOP("2 Months"), 2 * 60 * 60 * 24 * 30},
-                                  {I18N_NOOP("3 Months"), 3 * 60 * 60 * 24 * 30},
-                                  {I18N_NOOP("4 Months"), 4 * 60 * 60 * 24 * 30},
-                                  {I18N_NOOP("5 Months"), 5 * 60 * 60 * 24 * 30},
-                                  {I18N_NOOP("6 Months"), 6 * 60 * 60 * 24 * 30},
-                                  {I18N_NOOP("10 Months"), 10 * 60 * 60 * 24 * 30},
-                                  {I18N_NOOP("12 Months"), 12 * 60 * 60 * 24 * 30},
-                                  {0, 0}};
+                                  {kli18n("1 Month"), 1 * 60 * 60 * 24 * 30},
+                                  {kli18n("2 Months"), 2 * 60 * 60 * 24 * 30},
+                                  {kli18n("3 Months"), 3 * 60 * 60 * 24 * 30},
+                                  {kli18n("4 Months"), 4 * 60 * 60 * 24 * 30},
+                                  {kli18n("5 Months"), 5 * 60 * 60 * 24 * 30},
+                                  {kli18n("6 Months"), 6 * 60 * 60 * 24 * 30},
+                                  {kli18n("10 Months"), 10 * 60 * 60 * 24 * 30},
+                                  {kli18n("12 Months"), 12 * 60 * 60 * 24 * 30},
+                                  {KLazyLocalizedString(), 0}};
 
 BlockOptions::BlockOptions(QWidget *parent)
     : QWidget(parent)
@@ -156,8 +156,8 @@ void BlockOptions::fillComboBox(KComboBox *cb)
     ListRef *ref = date_itemlist;
 
     cb->clear();
-    while (ref->text != 0) {
-        cb->addItem(i18n(ref->text));
+    while (!KLocalizedString(ref->text).toString().isEmpty()) {
+        cb->addItem(KLocalizedString(ref->text).toString());
         ref++;
     }
 }
@@ -166,8 +166,7 @@ void BlockOptions::updateComboBox(int value, KComboBox *cb)
 {
     ListRef *ref = date_itemlist;
     int index = 0;
-
-    while (ref->text != 0) {
+    while (!KLocalizedString(ref->text).toString().isEmpty()) {
         if (value == ref->num)
             index = ref - date_itemlist;
         ref++;
@@ -205,7 +204,7 @@ void BlockOptions::slotExpireToggled(bool state)
 
 void BlockOptions::slotComboBoxActivated(int)
 {
-    emit widgetModified();
+    Q_EMIT widgetModified();
     checkValidity();
 }
 
@@ -253,7 +252,7 @@ void BlockOptions::checkValidity()
     }
 
     if (message.length() != 0)
-        KMessageBox::sorry(this, message, i18n("Illogical Values"));
+        KMessageBox::error(this, message, i18n("Illogical Values"));
 }
 
 bool BlockOptions::isDefault()
