@@ -14,7 +14,7 @@ class SpecificPracticeOptions : public QWidget, public Ui::SpecificPracticeOptio
 {
     Q_OBJECT
 public:
-    explicit SpecificPracticeOptions(QWidget* parent = 0);
+    explicit SpecificPracticeOptions(QWidget *parent = nullptr);
 };
 
 #endif
